Converts a table that has been read from DuckDB into an sf object.
convert_to_sf_wkb(data, crs, crs_column, x_geom)sf
a tibble or data frame
The coordinates reference system of the data. Specify if the data
doesn't have a crs_column, and you know the CRS.
a character string of length one specifying the column
storing the CRS (created automatically by ddbs_write_vector).
Set to NULL if absent.
name of geometry column