| ddbs_affine | R Documentation |
Applies an affine transformation to geometries using a 2x3 or 3x4 matrix.
ddbs_affine(
x,
matrix,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
matrix |
A numeric matrix specifying the transformation:
|
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load package
library(duckspatial)
## read data
argentina_ddbs <- ddbs_open_dataset(
system.file("spatial/argentina.geojson",
package = "duckspatial")
)
## 2D translation (shift x by 1, y by 2)
mat_2d <- matrix(c(1, 0, 1,
0, 1, 2), nrow = 2, byrow = TRUE)
ddbs_affine(argentina_ddbs, mat_2d)
## 2D scaling (scale x by 2, y by 3)
mat_scale <- matrix(c(2, 0, 0,
0, 3, 0), nrow = 2, byrow = TRUE)
ddbs_affine(argentina_ddbs, mat_scale)
## 3D transformation
mat_3d <- matrix(c(1, 0, 0, 1,
0, 1, 0, 2,
0, 0, 1, 0), nrow = 3, byrow = TRUE)
ddbs_affine(argentina_ddbs, mat_3d)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.