View source: R/ddbs_ops_unary.R
| ddbs_buffer | R Documentation |
Computes a polygon that represents all locations within a specified distance from the original geometry
ddbs_buffer(
x,
distance,
num_triangles = 8L,
cap_style = "CAP_ROUND",
join_style = "JOIN_ROUND",
mitre_limit = 1,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
distance |
a numeric value specifying the buffer distance. Units correspond to the coordinate system of the geometry (e.g. degrees or meters) |
num_triangles |
an integer representing how many triangles will be produced to approximate a quarter circle. The larger the number, the smoother the resulting geometry. Default is 8. |
cap_style |
a character string specifying the cap style. Must be one of "CAP_ROUND" (default), "CAP_FLAT", or "CAP_SQUARE". Case-insensitive. |
join_style |
a character string specifying the join style. Must be one of "JOIN_ROUND" (default), "JOIN_MITRE", or "JOIN_BEVEL". Case-insensitive. |
mitre_limit |
a numeric value specifying the mitre limit ratio. Only applies when
|
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load package
library(duckspatial)
## create a duckdb database in memory (with spatial extension)
conn <- ddbs_create_conn(dbdir = "memory")
## read data
argentina_ddbs <- ddbs_open_dataset(
system.file("spatial/argentina.geojson",
package = "duckspatial")
)
## store in duckdb
ddbs_write_vector(conn, argentina_ddbs, "argentina")
## basic buffer
ddbs_buffer(conn = conn, "argentina", distance = 1)
## buffer with custom parameters
ddbs_buffer(conn = conn, "argentina", distance = 1,
num_triangles = 16, cap_style = "CAP_SQUARE")
## buffer without using a connection
ddbs_buffer(argentina_ddbs, distance = 1)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.