View source: R/ddbs_ops_unary_line.R
| ddbs_build_area | R Documentation |
Constructs polygon or multipolygon geometries from a collection of linestrings,
handling intersections and creating unified areas. Returns POLYGON or MULTIPOLYGON
(not wrapped in a geometry collection). Requires MULTILINESTRING input - for
single linestrings, use ddbs_make_polygon().
ddbs_build_area(
x,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
ddbs_make_polygon(), ddbs_polygonize()
Other polygon construction:
ddbs_make_polygon(),
ddbs_polygonize()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.