| ddbs_endpoint_startpoint | R Documentation |
Returns the first or last point of a LINESTRING geometry. These functions only work with LINESTRING geometries (not MULTILINESTRING or other geometry types).
ddbs_line_startpoint(
x,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
ddbs_line_endpoint(
x,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
These functions wrap DuckDB Spatial's ST_StartPoint and ST_EndPoint.
Input geometries must be of type LINESTRING (MULTILINESTRING is not supported).
For each input feature, the first or last coordinate of the LINESTRING is returned
as a POINT geometry.
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load package
library(duckspatial)
## create a duckdb database in memory (with spatial extension)
conn <- ddbs_create_conn(dbdir = "memory")
## read data
rivers_ddbs <- ddbs_open_dataset(
system.file("spatial/rivers.geojson",
package = "duckspatial")
)
## store in duckdb
ddbs_write_vector(conn, rivers_ddbs, "rivers")
## extract start points
ddbs_line_startpoint(conn = conn, "rivers")
## extract end points
ddbs_line_endpoint(conn = conn, "rivers")
## without using a connection
ddbs_line_startpoint(rivers_ddbs)
ddbs_line_endpoint(rivers_ddbs)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.