| ddbs_glimpse | R Documentation |
Prints a transposed table of the first rows of a DuckDB table, similarly as the S3 dplyr::glimpse method.
ddbs_glimpse(conn, name, quiet = FALSE)
conn |
A |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
quiet |
A logical value. If |
Invisibly duckspatial_df object
## Not run:
library(duckspatial)
# create a duckdb database in memory (with spatial extension)
conn <- ddbs_create_conn(dbdir = "memory")
## read data
argentina_sf <- ddbs_open_dataset(system.file("spatial/argentina.geojson", package = "duckspatial"))
## store in duckdb
ddbs_write_table(conn, argentina_sf, "argentina")
## glimpse the inserted table
ddbs_glimpse(conn, "argentina")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.