View source: R/ddbs_ops_unary_line.R
| ddbs_line_interpolate | R Documentation |
Returns either a single point at a specified position along a line, or
multiple equally-spaced points along a line, depending on the value of
intervals. When intervals = FALSE, this wraps
ST_LineInterpolatePoint; when intervals = TRUE, it wraps
ST_LineInterpolatePoints.
ddbs_line_interpolate(
x,
fraction = 0.5,
intervals = FALSE,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
fraction |
a numeric value between 0 and 1. When
|
intervals |
a logical value. If |
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load package
library(duckspatial)
## read data
rivers_ddbs <- ddbs_open_dataset(
system.file("spatial/rivers.geojson",
package = "duckspatial")
)
## return the midpoint of a line (default)
ddbs_line_interpolate(rivers_ddbs)
## return the point 25% along the line
ddbs_line_interpolate(rivers_ddbs, fraction = 0.25)
## return equally-spaced points every 10% of the line length
ddbs_line_interpolate(rivers_ddbs, fraction = 0.1, intervals = TRUE)
## return equally-spaced points every 50% of the line length (i.e. midpoint and end)
ddbs_line_interpolate(rivers_ddbs, fraction = 0.5, intervals = TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.