View source: R/ddbs_ops_unary_line.R
| ddbs_line_merge | R Documentation |
Merges a collection of line geometries that share endpoints into a single
LINESTRING, or MULTILINESTRING if endpoints are not shared
ddbs_line_merge(
x,
preserve = TRUE,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
preserve |
a logical value. If |
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load package
library(duckspatial)
library(dplyr)
## read data
rivers_ddbs <- ddbs_open_dataset(
system.file("spatial/rivers.geojson",
package = "duckspatial")
)
## first, union by river name
rivers_union <- ddbs_union_agg(rivers_ddbs, by = "RIVER_NAME")
## merge lines, preserving direction
rivers_merged <- ddbs_line_merge(rivers_union)
## check Rio Eume (union doesn't guarantee the merging)
rivers_union |> filter(RIVER_NAME == "Rio Eume")
rivers_merged |> filter(RIVER_NAME == "Rio Eume")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.