View source: R/ddbs_ops_unary_line.R
| ddbs_line_substring | R Documentation |
Returns the portion of a line between two fractional positions along its length
ddbs_line_substring(
x,
start = 0,
end = 0.5,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
start |
a numeric value between 0 and 1. Specifies the starting
position along the line as a proportion of its total length, where
|
end |
a numeric value between 0 and 1. Specifies the ending
position along the line as a proportion of its total length, where
|
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load package
library(duckspatial)
## read data
rivers_ddbs <- ddbs_open_dataset(
system.file("spatial/rivers.geojson",
package = "duckspatial")
)
## return the first half of each line (default)
ddbs_line_substring(rivers_ddbs)
## return the middle third of each line
ddbs_line_substring(rivers_ddbs, start = 0.33, end = 0.67)
## return the last quarter of each line
ddbs_line_substring(rivers_ddbs, start = 0.75, end = 1)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.