| ddbs_load | R Documentation |
Checks if a spatial extension is installed, and loads it in a DuckDB database
ddbs_load(conn, quiet = FALSE, extension = "spatial", create_macros = TRUE)
conn |
A |
quiet |
A logical value. If |
extension |
name of the extension to load, default is "spatial" |
create_macros |
if TRUE (default), it creates macros that allow some functions to be used within dplyr pipelines |
TRUE (invisibly) for successful installation
## Not run:
## load packages
library(duckspatial)
library(duckdb)
## connect to in memory database
conn <- duckdb::dbConnect(duckdb::duckdb())
## install the spatial exntesion
ddbs_install(conn)
ddbs_load(conn)
## disconnect from db
duckdb::dbDisconnect(conn)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.