View source: R/ddbs_extent_funs.R
| ddbs_make_envelope | R Documentation |
Creates a rectangular POLYGON geometry from four bounding coordinates.
ddbs_make_envelope(
xmin,
ymin,
xmax,
ymax,
crs = "EPSG:4326",
name = NULL,
conn = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
xmin |
A numeric value for the minimum X (longitude) coordinate. |
ymin |
A numeric value for the minimum Y (latitude) coordinate. |
xmax |
A numeric value for the maximum X (longitude) coordinate. |
ymax |
A numeric value for the maximum Y (latitude) coordinate. |
crs |
A character string specifying the coordinate reference system
of the output geometry. Default is |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
conn |
A connection object to a DuckDB database. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load package
library(duckspatial)
## without storing in duckdb
finland_bbox_ddbs <- ddbs_make_envelope(
xmin = 19.1, ymin = 59.7,
xmax = 31.6, ymax = 70.1
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.