View source: R/ddbs_ops_unary.R
| ddbs_make_line | R Documentation |
Aggregates point geometries into a single LINESTRING by connecting them in
their original order. Optionally, lines can be created per group using the
by argument.
ddbs_make_line(
x,
by = NULL,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
by |
A character vector of column names to group by before aggregating
points into lines. If |
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Connects input POINT geometries into a LINESTRING in row order (row 1 → row 2 → …).
To control the connection order, sort the data beforehand with dplyr::arrange().
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load package
library(duckspatial)
## read data
points_ddbs <- ddbs_open_dataset(
system.file("spatial/points.gpkg", package = "duckspatial")
)
## create a single line from all points
ddbs_make_line(points_ddbs)
## create lines grouped by a column
ddbs_make_line(points_ddbs, by = "type")
## return as sf object
ddbs_make_line(points_ddbs, by = "type", mode = "sf")
## screate lines groupping by 2 columns
ddbs_make_line(points_ddbs, by = c("type", "class"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.