| ddbs_options | R Documentation |
Get or set global duckspatial options
ddbs_options(output_type = NULL, mode = NULL, duckdb_storage_version = NULL)
output_type |
Character string. Controls the default return type for ddbs_collect. Must be one of:
If |
mode |
Character. Controls the return type. Options:
If |
duckdb_storage_version |
Character. The default DuckDB storage compatibility version for newly created database files. See https://duckdb.org/docs/internals/storage for details. |
Invisibly returns a list containing the currently set options.
## Not run:
# Set default mode to geoarrow
ddbs_options(mode = "geoarrow")
# Set default output to tibble
ddbs_options(output_type = "tibble")
# Check current settings
ddbs_options()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.