View source: R/ddbs_as_spatial.R
| ddbs_point | R Documentation |
Constructs POINT geometries from numeric coordinate vectors, optionally including Z (elevation) and M (measure) dimensions and extra attribute columns.
ddbs_point(
x,
y,
z = NULL,
m = NULL,
...,
crs = NULL,
geom_col = "geometry",
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Numeric vector of X (longitude) coordinates. |
y |
Numeric vector of Y (latitude) coordinates. |
z |
Optional numeric vector of Z (elevation) coordinates. |
m |
Optional numeric vector of M (measure) coordinates. Requires
|
... |
Named vectors of additional attribute columns to include in the
output. Each must have the same length as |
crs |
Character or numeric CRS specification (e.g. |
geom_col |
Name of the geometry column in the output. Defaults to
|
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
library(duckspatial)
## 2D points
ddbs_point(
x = c(-58.38, -64.18, -60.64),
y = c(-34.60, -31.42, -32.95),
crs = 4326
)
## 3D points with extra columns
ddbs_point(
x = c(0, 1, 2),
y = c(0, 1, 2),
z = c(10, 20, 30),
id = 1:3,
crs = 4326
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.