| ddbs_read_vector | R Documentation |
ddbs_read_vector() was renamed to ddbs_read_table.
ddbs_read_vector(conn, name, clauses = NULL, quiet = FALSE)
conn |
A |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
clauses |
character, additional SQL code to modify the query from the table (e.g. "WHERE ...", "ORDER BY...") |
quiet |
A logical value. If |
an sf object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.