| ddbs_register_vector | R Documentation |
ddbs_register_vector() was renamed to ddbs_register_table.
ddbs_register_vector(conn, data, name, overwrite = FALSE, quiet = FALSE)
conn |
A |
data |
A |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
TRUE (invisibly) on successful registration.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.