View source: R/ddbs_ops_unary.R
| ddbs_remove_repeated_points | R Documentation |
Removes duplicate consecutive vertices from geometries, optionally within a tolerance distance.
ddbs_remove_repeated_points(
x,
tolerance = 0,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
tolerance |
A numeric value specifying the minimum distance between
consecutive vertices. Vertices closer than this threshold are considered
repeated and removed. Default is |
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load package
library(duckspatial)
library(sf)
## Create a polygon with repeated points
poly <- st_polygon(list(matrix(
c(0, 0,
1, 0,
1, 0, # repeated point
1, 1,
0, 1,
0, 0),
ncol = 2, byrow = TRUE
)))
poly_sf <- st_as_sf(st_sfc(poly))
## remove exact duplicate consecutive vertices
ddbs_remove_repeated_points(poly_sf)
## remove vertices within a tolerance of 1 unit
ddbs_remove_repeated_points(poly_sf, tolerance = 1)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.