| ddbs_rotate_3d | R Documentation |
Rotates 3D geometries by a specified angle around the X, Y, or Z axis, preserving their shape.
ddbs_rotate_3d(
x,
angle,
units = c("degrees", "radians"),
axis = "x",
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
angle |
a numeric value specifying the rotation angle |
units |
character string specifying angle units: "degrees" (default) or "radians" |
axis |
character string specifying the rotation axis: "x", "y", or "z" (default = "x"). The geometry rotates around this axis |
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load packages
library(duckspatial)
library(dplyr)
# create a duckdb database in memory (with spatial extension)
conn <- ddbs_create_conn(dbdir = "memory")
## read 3D data
countries_ddbs <- ddbs_open_dataset(
system.file("spatial/countries.geojson",
package = "duckspatial")
) |>
filter(CNTR_ID %in% c("PT", "ES", "FR", "IT"))
## store in duckdb
ddbs_write_table(conn, countries_ddbs, "countries")
## rotate 45 degrees around X axis (pitch)
ddbs_rotate_3d(conn = conn, "countries", angle = 45, axis = "x")
## rotate 90 degrees around Y axis (yaw)
ddbs_rotate_3d(conn = conn, "countries", angle = 30, axis = "y")
## rotate 180 degrees around Z axis (roll)
ddbs_rotate_3d(conn = conn, "countries", angle = 180, axis = "z")
## rotate without using a connection
ddbs_rotate_3d(countries_ddbs, angle = 45, axis = "z")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.