View source: R/ddbs_ops_unary.R
| ddbs_simplify | R Documentation |
Reduces the complexity of geometries by removing unnecessary vertices while preserving the overall shape.
ddbs_simplify(
x,
tolerance = 0,
preserve_topology = FALSE,
conn = NULL,
name = NULL,
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)
x |
Input spatial data. Can be:
Data is returned from this object. |
tolerance |
Tolerance distance for simplification. Larger values result in more simplified geometries. |
preserve_topology |
If FALSE, uses the Douglas-Peucker algorithm, which reduces the vertices by removing points that are within a given distance. If TRUE, uses a topology-preserving variant of Douglas-Peucker that guarantees the output geometry remains valid (slower). |
conn |
A connection object to a DuckDB database. If |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
mode |
Character. Controls the return type. Options:
Can be set globally via |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
quiet |
A logical value. If |
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial (default): A duckspatial_df (lazy spatial data frame) backed by dbplyr/DuckDB.
sf: An eagerly collected object in R memory, that will return the same data type as the
sf equivalent (e.g. sf or units vector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
## Not run:
## load package
library(duckspatial)
# create a duckdb database in memory (with spatial extension)
conn <- ddbs_create_conn(dbdir = "memory")
## read data
countries_ddbs <- ddbs_open_dataset(
system.file("spatial/countries.geojson",
package = "duckspatial")
)
## store in duckdb
ddbs_write_vector(conn, countries_ddbs, "countries")
## simplify with tolerance of 0.01
ddbs_simplify("countries", tolerance = 0.01, conn = conn)
## simplify without using a connection
ddbs_simplify(countries_ddbs, tolerance = 0.01)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.