| ddbs_sitrep | R Documentation |
Displays useful information about the current configuration, including global options and the status of the default DuckDB connection.
ddbs_sitrep()
Invisibly returns a list with the current status configuration.
ddbs_sitrep()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.