| ddbs_write_vector | R Documentation |
ddbs_write_vector() was renamed to ddbs_write_table.
ddbs_write_vector(
conn,
data,
name,
overwrite = FALSE,
temp_view = FALSE,
quiet = FALSE
)
conn |
A |
data |
A |
name |
A character string of length one specifying the name of the table,
or a character string of length two specifying the schema and table
names. If |
overwrite |
Boolean. whether to overwrite the existing table if it exists. Defaults
to |
temp_view |
If |
quiet |
A logical value. If |
TRUE (invisibly) for successful import
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.