| duckspatial-package | R Documentation |
Fast & memory-efficient functions to analyze and manipulate large spatial data data sets. It leverages the fast analytical capabilities of 'DuckDB' and its spatial extension (see https://duckdb.org/docs/stable/core_extensions/spatial/overview) while maintaining compatibility with R’s spatial data ecosystem to work with spatial vector data.
Maintainer: Adrián Cidre González adrian.cidre@gmail.com (ORCID)
Authors:
Adrián Cidre González adrian.cidre@gmail.com (ORCID)
Egor Kotov kotov.egor@gmail.com (ORCID)
Rafael H. M. Pereira rafa.pereira.br@gmail.com (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.