Converts a data frame with coordinate columns into spatial point geometries.
Usage
ddbs_as_spatial(
x,
coords = c("lon", "lat"),
crs = "EPSG:4326",
conn = NULL,
name = NULL,
crs_column = "crs_duckspatial",
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)Arguments
- x
Input spatial data. Can be:
A
duckspatial_dfobject (lazy spatial data frame via dbplyr)An
sfobjectA
tbl_lazyfrom dbplyrA character string naming a table/view in
conn
Data is returned from this object.
- coords
Character vector of length 2 specifying the names of the longitude and latitude columns (or X and Y coordinates). Defaults to
c("lon", "lat").- crs
Character or numeric. The Coordinate Reference System (CRS) of the input coordinates. Can be specified as an EPSG code (e.g.,
"EPSG:4326"or4326) or a WKT string. Defaults to"EPSG:4326"(WGS84 longitude/latitude).- conn
A connection object to a DuckDB database. If
NULL, the function runs on a temporary DuckDB database.- name
A character string of length one specifying the name of the table, or a character string of length two specifying the schema and table names. If
NULL(the default), the function returns the result as ansfobject- crs_column
Deprecated a character string of length one specifying the column storing the CRS (created automatically by
ddbs_write_table). Set toNULLif absent.- mode
Character. Controls the return type. Options:
"duckspatial"(default): Lazy spatial data frame backed by dbplyr/DuckDB"sf": Eagerly collected sf object (uses memory)
Can be set globally via
ddbs_options(mode = "...")or per-function via this argument. Per-function overrides global setting.- overwrite
Boolean. whether to overwrite the existing table if it exists. Defaults to
FALSE. This argument is ignored whennameisNULL.- quiet
A logical value. If
TRUE, suppresses any informational messages. Defaults toFALSE.
Value
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial(default): Aduckspatial_df(lazy spatial data frame) backed by dbplyr/DuckDB.sf: An eagerly collected object in R memory, that will return the same data type as thesfequivalent (e.g.sforunitsvector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
Examples
if (FALSE) { # \dontrun{
## load packages
library(duckspatial)
## create sample data with coordinates
cities_df <- data.frame(
city = c("Buenos Aires", "Córdoba", "Rosario"),
lon = c(-58.3816, -64.1811, -60.6393),
lat = c(-34.6037, -31.4201, -32.9468),
population = c(3075000, 1391000, 1193605)
)
# option 1: convert data frame to sf object
cities_ddbs <- ddbs_as_spatial(cities_df)
# specify custom coordinate column names
cities_df2 <- data.frame(
city = c("Mendoza", "Tucumán"),
longitude = c(-68.8272, -65.2226),
latitude = c(-32.8895, -26.8241)
)
ddbs_as_spatial(cities_df2, coords = c("longitude", "latitude"))
## option 2: convert table in duckdb to spatial table
# create a duckdb connection and write data
conn <- duckspatial::ddbs_create_conn()
DBI::dbWriteTable(conn, "cities_tbl", cities_df, overwrite = TRUE)
# convert to spatial table in database
ddbs_as_spatial(
x = "cities_tbl",
conn = conn,
name = "cities_spatial",
overwrite = TRUE
)
# read the spatial table
ddbs_read_table(conn, "cities_spatial")
} # }