Returns the concave hull that tightly encloses the geometry, capturing its overall shape more closely than a convex hull.
Usage
ddbs_concave_hull(
x,
ratio = 0.5,
allow_holes = TRUE,
conn = NULL,
name = NULL,
crs = NULL,
crs_column = "crs_duckspatial",
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)Arguments
- x
Input spatial data. Can be:
A
duckspatial_dfobject (lazy spatial data frame via dbplyr)An
sfobjectA
tbl_lazyfrom dbplyrA character string naming a table/view in
conn
Data is returned from this object.
- ratio
Numeric. The ratio parameter dictates the level of concavity;
1returns the convex hull, while0indicates to return the most concave hull possible. Defaults to0.5.- allow_holes
Boolean. If
TRUE(the default), it allows the output to contain holes.- conn
A connection object to a DuckDB database. If
NULL, the function runs on a temporary DuckDB database.- name
A character string of length one specifying the name of the table, or a character string of length two specifying the schema and table names. If
NULL(the default), the function returns the result as ansfobject- crs
Deprecated The coordinates reference system of the data. Specify if the data doesn't have a
crs_column, and you know the CRS.- crs_column
Deprecated a character string of length one specifying the column storing the CRS (created automatically by
ddbs_write_vector). Set toNULLif absent.- mode
Character. Controls the return type. Options:
"duckspatial"(default): Lazy spatial data frame backed by dbplyr/DuckDB"sf": Eagerly collected sf object (uses memory)
Can be set globally via
ddbs_options(mode = "...")or per-function via this argument. Per-function overrides global setting.- overwrite
Boolean. whether to overwrite the existing table if it exists. Defaults to
FALSE. This argument is ignored whennameisNULL.- quiet
A logical value. If
TRUE, suppresses any informational messages. Defaults toFALSE.
Value
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial(default): Aduckspatial_df(lazy spatial data frame) backed by dbplyr/DuckDB.sf: An eagerly collected object in R memory, that will return the same data type as thesfequivalent (e.g.sforunitsvector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
Examples
if (FALSE) { # \dontrun{
## load package
library(duckspatial)
library(sf)
# create points data
n <- 5
points_ddbs <- data.frame(
id = 1,
x = runif(n, min = -180, max = 180),
y = runif(n, min = -90, max = 90)
) |>
ddbs_as_spatial(coords = c("x", "y"), crs = 4326) |>
ddbs_combine()
# option 1: passing ddbs or sf objects
output1 <- duckspatial::ddbs_concave_hull(points_ddbs, mode = "sf")
plot(output1)
# option 2: passing the name of a table in a duckdb db
# creates a duckdb
conn <- duckspatial::ddbs_create_conn()
# write sf to duckdb
ddbs_write_vector(conn, points_ddbs, "points_tbl")
# spatial join
output2 <- duckspatial::ddbs_concave_hull(
conn = conn,
x = "points_tbl",
mode = "sf"
)
plot(output2)
} # }