ddbs_glimpse: Check first rows of the data

View source: R/db_utils.R

ddbs_glimpseR Documentation

Check first rows of the data

Description

Check first rows of the data

Usage

ddbs_glimpse(conn, name, crs = NULL, crs_column = "crs_duckspatial")

Arguments

conn

a connection object to a DuckDB database

name

a character string of length one specifying the name of the table, or a character string of length two specifying the schema and table names.

crs

the coordinates reference system of the data. Specify if the data doesn't have crs_column, and you know the crs

crs_column

a character string of length one specifying the column storing the CRS (created automatically by ddbs_write_vector)

Value

sf object

Examples


## TODO


duckspatial documentation built on June 8, 2025, 1:08 p.m.