| ddbs_glimpse | R Documentation |
Check first rows of the data
ddbs_glimpse(conn, name, crs = NULL, crs_column = "crs_duckspatial")
conn |
a connection object to a DuckDB database |
name |
a character string of length one specifying the name of the table, or a character string of length two specifying the schema and table names. |
crs |
the coordinates reference system of the data. Specify if the data doesn't have crs_column, and you know the crs |
crs_column |
a character string of length one specifying the column
storing the CRS (created automatically by |
sf object
## TODO
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.