ddbs_read_vector() was renamed to ddbs_read_table.
Arguments
- conn
A
DBIConnectionobject to a DuckDB database- name
A character string of length one specifying the name of the table, or a character string of length two specifying the schema and table names. If
NULL(the default), the function returns the result as ansfobject- clauses
character, additional SQL code to modify the query from the table (e.g. "WHERE ...", "ORDER BY...")
- quiet
A logical value. If
TRUE, suppresses any informational messages. Defaults toFALSE.