Rotates 3D geometries by a specified angle around the X, Y, or Z axis, preserving their shape.
Usage
ddbs_rotate_3d(
x,
angle,
units = c("degrees", "radians"),
axis = "x",
conn = NULL,
name = NULL,
crs = NULL,
crs_column = "crs_duckspatial",
mode = NULL,
overwrite = FALSE,
quiet = FALSE
)Arguments
- x
Input spatial data. Can be:
A
duckspatial_dfobject (lazy spatial data frame via dbplyr)An
sfobjectA
tbl_lazyfrom dbplyrA character string naming a table/view in
conn
Data is returned from this object.
- angle
a numeric value specifying the rotation angle
- units
character string specifying angle units: "degrees" (default) or "radians"
- axis
character string specifying the rotation axis: "x", "y", or "z" (default = "x"). The geometry rotates around this axis
- conn
A connection object to a DuckDB database. If
NULL, the function runs on a temporary DuckDB database.- name
A character string of length one specifying the name of the table, or a character string of length two specifying the schema and table names. If
NULL(the default), the function returns the result as ansfobject- crs
Deprecated The coordinates reference system of the data. Specify if the data doesn't have a
crs_column, and you know the CRS.- crs_column
Deprecated a character string of length one specifying the column storing the CRS (created automatically by
ddbs_write_vector). Set toNULLif absent.- mode
Character. Controls the return type. Options:
"duckspatial"(default): Lazy spatial data frame backed by dbplyr/DuckDB"sf": Eagerly collected sf object (uses memory)
Can be set globally via
ddbs_options(mode = "...")or per-function via this argument. Per-function overrides global setting.- overwrite
Boolean. whether to overwrite the existing table if it exists. Defaults to
FALSE. This argument is ignored whennameisNULL.- quiet
A logical value. If
TRUE, suppresses any informational messages. Defaults toFALSE.
Value
Depends on the mode argument (or global preference set by ddbs_options):
duckspatial(default): Aduckspatial_df(lazy spatial data frame) backed by dbplyr/DuckDB.sf: An eagerly collected object in R memory, that will return the same data type as thesfequivalent (e.g.sforunitsvector).
When name is provided, the result is also written as a table or view in DuckDB and the function returns TRUE (invisibly).
Examples
if (FALSE) { # \dontrun{
## load packages
library(duckspatial)
library(dplyr)
# create a duckdb database in memory (with spatial extension)
conn <- ddbs_create_conn(dbdir = "memory")
## read 3D data
countries_ddbs <- ddbs_open_dataset(
system.file("spatial/countries.geojson",
package = "duckspatial")
) |>
filter(CNTR_ID %in% c("PT", "ES", "FR", "IT"))
## store in duckdb
ddbs_write_table(conn, countries_ddbs, "countries")
## rotate 45 degrees around X axis (pitch)
ddbs_rotate_3d(conn = conn, "countries", angle = 45, axis = "x")
## rotate 90 degrees around Y axis (yaw)
ddbs_rotate_3d(conn = conn, "countries", angle = 30, axis = "y")
## rotate 180 degrees around Z axis (roll)
ddbs_rotate_3d(conn = conn, "countries", angle = 180, axis = "z")
## rotate without using a connection
ddbs_rotate_3d(countries_ddbs, angle = 45, axis = "z")
} # }