Displays useful information about the current configuration, including global options and the status of the default DuckDB connection.
Examples
ddbs_sitrep()
#>
#> ── duckspatial Status Report ───────────────────────────────────────────────────
#>
#> ── Global Options ──
#>
#> • Output Type: "duckspatial_df"
#> • Mode: "duckspatial (default)"
#> • DuckDB Storage Version: "v1.5.0"
#>
#> ── Default Connection ──
#>
#> ✔ Active DuckDB connection found.