Displays useful information about the current configuration, including global options and the status of the default DuckDB connection.
Examples
ddbs_sitrep()
#>
#> ── duckspatial Status Report ───────────────────────────────────────────────────
#>
#> ── Global Options ──
#>
#> • Output Type: "duckspatial_df"
#> • Mode: "duckspatial (default)"
#>
#> ── Default Connection ──
#>
#> ! No default connection active (will be created on demand).