ddbs_write_vector() was renamed to ddbs_write_table.
Arguments
- conn
A
DBIConnectionobject to a DuckDB database- data
A
sfobject to write to the DuckDB database, or the path to a local file that can be read withST_READ- name
A character string of length one specifying the name of the table, or a character string of length two specifying the schema and table names. If
NULL(the default), the function returns the result as ansfobject- overwrite
Boolean. whether to overwrite the existing table if it exists. Defaults to
FALSE. This argument is ignored whennameisNULL.- temp_view
If
TRUE, registers thesfobject as a temporary Arrow-backed database 'view' usingddbs_register_tableinstead of creating a persistent table. This is much faster but the view will not persist. Defaults toFALSE.- quiet
A logical value. If
TRUE, suppresses any informational messages. Defaults toFALSE.